package MFDouble;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFDouble;
our $SField = new SFDouble;

1;
__END__
